@@ -18,6 +18,16 @@ function _aws_cdk_aws_sns_TopicProps(p) {
 }
 function _aws_cdk_aws_sns_CfnSubscriptionProps(p) {
 }
+function _aws_cdk_aws_sns_TopicSubscriptionConfig(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.protocol))
+        _aws_cdk_aws_sns_SubscriptionProtocol(p.protocol);
+    if (!visitedObjects.has(p.filterPolicy))
+        _aws_cdk_aws_sns_SubscriptionFilter(p.filterPolicy);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_aws_sns_SubscriptionProps(p) {
     if (p == null)
         return;
@@ -30,18 +40,6 @@ function _aws_cdk_aws_sns_SubscriptionProps(p) {
         _aws_cdk_aws_sns_SubscriptionFilter(p.filterPolicy);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_sns_TopicSubscriptionConfig(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    if (!visitedObjects.has(p.protocol))
-        _aws_cdk_aws_sns_SubscriptionProtocol(p.protocol);
-    if (!visitedObjects.has(p.filterPolicy))
-        _aws_cdk_aws_sns_SubscriptionFilter(p.filterPolicy);
-    visitedObjects.delete(p);
-}
-function _aws_cdk_aws_sns_ITopicSubscription(p) {
-}
 function _aws_cdk_aws_sns_TopicPolicyProps(p) {
     if (p == null)
         return;
@@ -50,6 +48,8 @@ function _aws_cdk_aws_sns_TopicPolicyProps(p) {
         _aws_cdk_aws_sns_ITopic(p.topics);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_sns_ITopicSubscription(p) {
+}
 function _aws_cdk_aws_sns_NumericConditions(p) {
     if (p == null)
         return;
@@ -78,10 +78,10 @@ function _aws_cdk_aws_sns_Subscription(p) {
 }
 function _aws_cdk_aws_sns_Topic(p) {
 }
-function _aws_cdk_aws_sns_CfnTopicPolicy(p) {
-}
 function _aws_cdk_aws_sns_SubscriptionFilter(p) {
 }
+function _aws_cdk_aws_sns_CfnTopicPolicy(p) {
+}
 function _aws_cdk_aws_sns_CfnSubscription(p) {
 }
 function _aws_cdk_aws_sns_CfnTopicProps(p) {
@@ -115,5 +115,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_sns_SubscriptionProtocol, _aws_cdk_aws_sns_BetweenCondition, _aws_cdk_aws_sns_CfnTopicPolicyProps, _aws_cdk_aws_sns_StringConditions, _aws_cdk_aws_sns_TopicProps, _aws_cdk_aws_sns_CfnSubscriptionProps, _aws_cdk_aws_sns_SubscriptionProps, _aws_cdk_aws_sns_TopicSubscriptionConfig, _aws_cdk_aws_sns_ITopicSubscription, _aws_cdk_aws_sns_TopicPolicyProps, _aws_cdk_aws_sns_NumericConditions, _aws_cdk_aws_sns_SubscriptionOptions, _aws_cdk_aws_sns_TopicPolicy, _aws_cdk_aws_sns_Subscription, _aws_cdk_aws_sns_Topic, _aws_cdk_aws_sns_CfnTopicPolicy, _aws_cdk_aws_sns_SubscriptionFilter, _aws_cdk_aws_sns_CfnSubscription, _aws_cdk_aws_sns_CfnTopicProps, _aws_cdk_aws_sns_CfnTopic, _aws_cdk_aws_sns_CfnTopic_SubscriptionProperty, _aws_cdk_aws_sns_ITopic, _aws_cdk_aws_sns_TopicBase };
+module.exports = { print, _aws_cdk_aws_sns_SubscriptionProtocol, _aws_cdk_aws_sns_BetweenCondition, _aws_cdk_aws_sns_CfnTopicPolicyProps, _aws_cdk_aws_sns_StringConditions, _aws_cdk_aws_sns_TopicProps, _aws_cdk_aws_sns_CfnSubscriptionProps, _aws_cdk_aws_sns_TopicSubscriptionConfig, _aws_cdk_aws_sns_SubscriptionProps, _aws_cdk_aws_sns_TopicPolicyProps, _aws_cdk_aws_sns_ITopicSubscription, _aws_cdk_aws_sns_NumericConditions, _aws_cdk_aws_sns_SubscriptionOptions, _aws_cdk_aws_sns_TopicPolicy, _aws_cdk_aws_sns_Subscription, _aws_cdk_aws_sns_Topic, _aws_cdk_aws_sns_SubscriptionFilter, _aws_cdk_aws_sns_CfnTopicPolicy, _aws_cdk_aws_sns_CfnSubscription, _aws_cdk_aws_sns_CfnTopicProps, _aws_cdk_aws_sns_CfnTopic, _aws_cdk_aws_sns_CfnTopic_SubscriptionProperty, _aws_cdk_aws_sns_ITopic, _aws_cdk_aws_sns_TopicBase };
 module.exports.DeprecationError = DeprecationError;
